'use strict';

// Require Electron modules
const app = require('electron').app;
const shell = require('electron').shell;
const ipc = require('electron').ipcMain;
const BrowserWindow = require('electron').BrowserWindow;
const Menu = require('electron').Menu;
const { ipcRenderer } = require('electron');
//const Badge = require('electron-windows-badge');
const Badge = require('electron-badge');
// Require Node modules
const path = require('path');
const fs = require('fs');
const appTitle = 'Dwike Projects';
// Require local modules
const storage = require('./storage');

// Get URL of Dwike Projects installation
const dpURL = storage.get('dpURL') || 'https://work.ingressit.com/';

// Require download component
require('electron-dl')({
    showBadge: false
});

let locale;
let mainWindow;
let isQuitting = false;



/**
 * Update count changed
 * @param  {event} e
 * @param  {number} count
 */
function onUpdateCountChanged(e, count) {
    if (app.dock) {
        app.dock.setBadge(count > 0 ? count + '' : '');
    } else {
        //ipcRenderer.sendSync('update-badge', count > 0 ? count + '' : '');
        //ipcRenderer.send('update-badge', count > 0 ? count + '' : '');
    }

    // if (count > 0) {
    //   systemTrayIcon.setHighlightMode('always');
    // } else {
    //   systemTrayIcon.setHighlightMode('never');
    // }
}



// Function for creating the main window
function createMainWindow() {
    // Open window with default size or last window state
    const lastWindowState = storage.get('lastWindowState') || { width: 1024, height: 768 };

    // Check if window was opened fullscreen
    const isFullscreen = storage.get('isFullscreen') || false;

    // Create new browser window
    const win = new BrowserWindow({
        title: appTitle,
        show: false,
        x: lastWindowState.x,
        y: lastWindowState.y,
        width: lastWindowState.width,
        height: lastWindowState.height,
        icon: process.platform === 'linux' && path.join(__dirname, 'media', 'Icon.png'),
        minWidth: 800,
        minHeight: 600,
        titleBarStyle: 'default',
        webPreferences: {
            nodeIntegration: false,
            preload: path.join(__dirname, 'browser.js'),
            webSecurity: true,
            plugins: false
        }

    });
    if (!app.dock) {
        const badgeOptions = {}
        new Badge(win, badgeOptions);
    }
    // Window close callback
    win.on('close', function(e) {
        if (process.platform == 'darwin' && !isQuitting) {
            e.preventDefault();
            win.hide();

        } else {
            app.quit();

        }

    });

    win.loadURL(dpURL, { userAgent: 'Palzin Electron' });
    win.setFullScreen(isFullscreen);
    //win.webContents.openDevTools()
    ipc.on('updateCountChanged', onUpdateCountChanged);

    return win;

}

// App ready callback
app.on('ready', function() {
    locale = app.getLocale();
    mainWindow = createMainWindow();

    const page = mainWindow.webContents;

    // Set application menu based on locale
    switch (locale) {
        case 'de': // German
            Menu.setApplicationMenu(require('./menus/de'));
            break;

        default: // Defaults to English
            Menu.setApplicationMenu(require('./menus/en'));

    }

    // Document ready callback
    page.on('dom-ready', function() {
        mainWindow.show();

    });

    // New window callback
    page.on('new-window', function(e, url) {
        e.preventDefault();

        if (/(work|my)\.ingressit\.com/.test(url)) {
            // Internal links
            mainWindow.loadURL(url, { userAgent: 'Palzin' });

        } else {
            // External link
            shell.openExternal(url);

        }

    });


});

// App activate callback
app.on('activate', function() {
    mainWindow.show();

});

// App before quit callback
app.on('before-quit', function() {
    isQuitting = true;

    if (!mainWindow.isFullScreen()) {
        storage.set('lastWindowState', mainWindow.getBounds());
        storage.set('isFullscreen', false);

    } else {
        storage.set('isFullscreen', true);

    }

});