const remote = require('electron').remote;
const app = remote.app;
const ipcRenderer = require('electron').ipcRenderer;
const shell = require('electron').shell;
const packageConfiguration = require('../package.json');
const body = document.querySelector('body');
const aboutName = document.getElementById('about_name');
const aboutVersion = document.getElementById('about_version');
const aboutButtonTerms = document.getElementById('about_button_terms');
const aboutButtonPrivacy = document.getElementById('about_button_privacy');
const aboutYear = document.getElementById('about_year');
const aboutCompanyName = document.getElementById('about_company_name');
const aboutChannel = document.getElementById('about_channel');
const aboutChannelSelect = aboutChannel.querySelector('select');

aboutName.innerHTML = app.getName();
aboutVersion.innerHTML = app.getVersion();
aboutYear.innerHTML = new Date().getFullYear();
aboutCompanyName.innerHTML = packageConfiguration['author']['name'];
aboutButtonTerms.addEventListener('click', buttonTermsClicked);
aboutButtonPrivacy.addEventListener('click', buttonPrivacyClicked);

// channel switcher initialization
var currentUpdaterChannel = app.config.getUpdaterChannel();
var currentUpdaterChannelAccess = app.config.getUpdaterChannelAccess();
if (currentUpdaterChannel != 'stable' || currentUpdaterChannelAccess != 'stable') {
  body.classList.add('about_with_channels');

  var option = document.createElement('option');
  option.text = 'Public Updates';
  option.value = 'stable';
  aboutChannelSelect.add(option);

  if (currentUpdaterChannelAccess == 'beta' || currentUpdaterChannelAccess == 'edge') {
    var option = document.createElement('option');
    option.text = 'Beta Updates';
    option.value = 'beta';
    aboutChannelSelect.add(option);
  }

  if (currentUpdaterChannelAccess == 'edge') {
    var option = document.createElement('option');
    option.text = 'Bleeding Edge Updates';
    option.value = 'edge';
    aboutChannelSelect.add(option);
  }

  aboutChannelSelect.value = currentUpdaterChannel;
  aboutChannelSelect.addEventListener('change', channelChanged);
}

function buttonTermsClicked() {
  shell.openExternal('https://www.dwike.com/terms-of-service/');
}

function buttonPrivacyClicked() {
  shell.openExternal('https://www.dwike.com/privacy-policy/');
}

/**
 * @param  {Object} event
 */
function keyPressed(event) {
  if (
    (event.which == 87 && (event.ctrlKey || event.metaKey)) ||
    (event.which == 27)
  ) {
    ipcRenderer.send('aboutCloseWindow');
    event.preventDefault();
    event.stopPropagation();
  }
}

/**
 * @param  {event} event
 */
function channelChanged(event) {
  app.config.setUpdaterChannel(aboutChannelSelect.value);
}

document.addEventListener("keydown", keyPressed);
