const remote = require('electron').remote;
const app = remote.app;
const {Menu, MenuItem} = remote;

/**
 * Assemble context menu depending on type
 *
 * @param  {String} nodeType
 * @return {Object}
 */
function assembleContextMenu(nodeType, element) {
  let contextMenu = [];

  if (nodeType == 'a') {
    contextMenu = contextMenu.concat([{
        'label'     : 'Open Link in Browser',
        'click'     : function () {
          window.DesktopApp.openUrlInBrowser(element.getAttribute('href'));
        }
    }, {
        'label'     : 'Copy Link Address',
        'click'     : function () {
          window.DesktopApp.copyToClipboard(element.getAttribute('href'), true);
        }
    }, {
        'type'      : 'separator',
    }]);
  }

  if (nodeType == 'input') {
    contextMenu = contextMenu.concat([{
      'label'       : 'Undo',
      'role'        : 'undo',
    }, {
      'label'       : 'Redo',
      'role'        : 'redo',
    }, {
      'type'        : 'separator',
    }, {
      'label'       : 'Cut',
      'role'        : 'cut',
    }, {
      'label'       : 'Copy',
      'role'        : 'copy',
    }, {
      'label'       : 'Paste',
      'role'        : 'paste',
    }, {
      'type'        : 'separator',
    }, {
      'label'       : 'Select all',
      'role'        : 'selectall',
    }]);
  } else {
    contextMenu = contextMenu.concat([{
      'label'       : 'Cut',
      'enabled'     : false
    }, {
      'label'       : 'Copy',
      'role'        : 'copy',
    }, {
      'label'       : 'Paste',
      'enabled'     : false
    }, {
      'type'        : 'separator',
    }, {
      'label'       : 'Reload',
      'click'       : function () {
        window.DesktopApp.reloadPage();
      }
    }, {
      'type'        : 'separator',
    }, {
      'label'       : 'Open Current Page in Browser',
      'click'       : function () {
        window.DesktopApp.openUrlInBrowser(window.location.href);
      }
    }, {
      'label'       : 'Copy Current Page Address',
      'click'       : function () {
        window.DesktopApp.copyToClipboard(window.location.href);
      }
    }]);
  }

  return Menu.buildFromTemplate(contextMenu);
}

module.exports = {
  'getInputMenu'   : assembleContextMenu
};
